
### <a name="manual"></a> Decoration block

Inserts table of content calculated from chapter blocks.

| Key       |      Description      | Default |
|:----------|:--------------------- |:----- |
| type      |  decoration                 |  
| default   |  (optional) Sets default decorations      |  True
| decorations  |  list of decorations used for this document, function pointers from decoration definitions    |  




Example:
```YAML
- type       : decoration
  default    : True
```

Back to [Documentation](../../../README.md#block_structure)
